# holophonor
**Live looping, unlimited!**

The **Holophonor** project is an plugin based architecture, designed to allow complex control of loops with a variety of hardware components and network controllers to allow complete control of any number of loops running simultaneously, even over multiple machines with large network latency!

## install
Clone this repo:

`git clone https://github.com/quaternionmedia/holophonor.git`

Install locally:

`pip install -e holophonor/`

## configure
change holophonor/main.py to match your configuration

## run
From a terminal, run:

`holophonor`

